@@ -44,7 +44,7 @@ def base_logger(log_name: str = 'default', file_path: str = './', mode: str = 'D
         fh.setFormatter(formatter)
         handlers.add(fh)
         #  这里进行判断，如果logger.handlers列表为空，则添加，否则，直接去写日志
-        if mode == 'DEBUG' or cmd_output:
+        if cmd_output:
             ch = logging.StreamHandler()
             ch.setLevel(log_level[mode])
             ch.setFormatter(formatter)
